==> canteenlib-3.0.1.tar.gz: Full Compatibility.md <==
# V tomto souboru je rozepsaná každá featura pro každou instituci. Je to takový to-do list

➖ - v instituci není featura potřeba
✅ - featura funguje
❌ - featura nefunguje
❓ - featura funguje částečně nebo nelze vyzkoušet

# Feature set

(featury na otestování u každé verze)

- Login
- Získej uživatele
  - kredit
  - jméno
  - Příjmení
  - Kategorie
  - Účet pro platby
  - Variabilní symbol
  - specifický symbol
  - Uživatelské jméno
- Jídelníček pro den
  - správný počet jídel
  - jídlo
    - název
    - cena
    - varianta
    - objednáno
    - lze objednat
    - na burze
    - alergeny
      - kódy
      - podrobnosti
      - název
    - rozdělení na kategorie
    - blokováno (vypršela platnost)
- Objednávání
  - funguje objednávání
  - funguje zrušení
- Burza
  - získání burzy
  - Objednávání z burzy
  - vložení jídla na burzu
  - zrušit vložení jídla na burzu

# Spš a G Na Třebešíně - verze 2.18.03

- Login ✅
- Získej uživatele ✅
  - kredit ✅
  - jméno ✅
  - Příjmení ✅
  - Kategorie ✅
  - Účet pro platby ✅
  - Variabilní symbol ✅
  - specifický symbol ❓
  - Uživatelské jméno ✅
- Jídelníček pro den ✅
  - správný počet jídel ❓ - v autojídelně vyřešeno wrapperem.
  - jídlo ✅
    - název ✅
    - cena ✅
    - varianta ✅
    - objednáno ✅
    - lze objednat ✅
    - na burze ✅
    - alergeny ✅
      - kódy ❌ - není dostupné na této verzi icanteen
      - podrobnosti ✅
      - název ✅
    - rozdělení na kategorie ✅
- Objednávání
  - funguje objednávání ✅
  - funguje zrušení ✅
- Burza
  - získání burzy ✅
  - Objednávání z burzy ✅
  - vložení jídla na burzu ✅
  - zrušit vložení jídla na burzu ✅
  - počet ➖

# Základní škola Ostrava, Matiční 5

- Login ✅
- Získej uživatele ✅
  - kredit ✅
  - jméno ✅
  - Příjmení ✅
  - Kategorie ✅
  - Účet pro platby ✅
  - Variabilní symbol ✅
  - specifický symbol ❓
  - Uživatelské jméno ✅
- Jídelníček pro den ✅
  - správný počet jídel ❓ - v autojídelně vyřešeno wrapperem.
  - jídlo ✅
    - název ✅ má dvě mezery
    - cena ✅
    - varianta ✅
    - objednáno ✅
    - lze objednat ✅
    - na burze ✅
    - alergeny ✅
      - kódy ✅
      - podrobnosti ✅
      - název ✅
    - rozdělení na kategorie ✅
- Objednávání
  - funguje objednávání ✅
  - funguje zrušení ✅
- Burza
  - získání burzy
  - Objednávání z burzy
  - vložení jídla na burzu ✅
  - zrušit vložení jídla na burzu ✅
  - počet ➖

==> canteenlib-4.0.0.tar.gz: Full Compatibility.md <==
# V tomto souboru je rozepsaná každá featura pro každou instituci. Je to takový to-do list

➖ - v instituci není featura potřeba nebo není v dané verzi icanteen

✅ - featura funguje

❌ - featura nefunguje

❓ - featura funguje částečně nebo nelze vyzkoušet

# Feature set

(featury na otestování u každé verze)

- Login
- Získej uživatele
  - kredit
  - jméno
  - Příjmení
  - Kategorie
  - Účet pro platby
  - Variabilní symbol
  - specifický symbol
  - Uživatelské jméno
- Jídelníček pro den
  - správný počet jídel
  - jídlo
    - název
    - cena
    - varianta
    - objednáno
    - lze objednat
    - na burze
    - alergeny
      - kódy
      - podrobnosti
      - název
    - rozdělení na kategorie
    - blokováno (vypršela platnost)
- Jídelníček pro měsíc
- Objednávání
  - funguje objednávání
  - funguje zrušení
- Burza
  - získání burzy
  - Objednávání z burzy
  - vložení jídla na burzu
  - zrušit vložení jídla na burzu
  - počet
- Výdejny (jiné lokace)

# Spš a G Na Třebešíně - verze 2.18.03

- Login ✅
- Získej uživatele ✅
  - kredit ✅
  - jméno ✅
  - Příjmení ✅
  - Kategorie ✅
  - Účet pro platby ✅
  - Variabilní symbol ✅
  - specifický symbol ❓
  - Uživatelské jméno ✅
- Jídelníček pro den ✅
  - správný počet jídel ✅
  - jídlo ✅
    - název ✅
    - cena ✅
    - varianta ✅
    - objednáno ✅
    - lze objednat ✅
    - na burze ✅
    - alergeny ✅
      - kódy ➖ - není dostupné na této verzi icanteen
      - podrobnosti ✅
      - název ✅
    - rozdělení na kategorie ✅
- Jídelníček pro měsíc ✅
- Objednávání
  - funguje objednávání ✅
  - funguje zrušení ✅
- Burza
  - získání burzy ✅
  - Objednávání z burzy ✅
  - vložení jídla na burzu ✅
  - zrušit vložení jídla na burzu ✅
  - počet ➖
- Výdejny (jiné lokace) ➖

# Základní škola Ostrava, Matiční 5

- Login ✅
- Získej uživatele ✅
  - kredit ✅
  - jméno ✅
  - Příjmení ✅
  - Kategorie ✅
  - Účet pro platby ✅
  - Variabilní symbol ✅
  - specifický symbol ❓
  - Uživatelské jméno ✅
- Jídelníček pro den ✅
  - správný počet jídel ✅
  - jídlo ✅
    - název ✅ má dvě mezery
    - cena ✅
    - varianta ✅
    - objednáno ✅
    - lze objednat ✅
    - na burze ✅
    - alergeny ✅
      - kódy ✅
      - podrobnosti ✅
      - název ✅
    - rozdělení na kategorie ✅
- Jídelníček pro měsíc ✅
- Objednávání
  - funguje objednávání ✅
  - funguje zrušení ✅
- Burza
  - získání burzy ✅
  - Objednávání z burzy ✅
  - vložení jídla na burzu ✅
  - zrušit vložení jídla na burzu ✅
  - počet ➖
- Výdejny (jiné lokace) ➖

# SOŠ stavební a SOU stavební Kolín

- Login ✅
- Získej uživatele ✅
  - kredit ✅
  - jméno ✅
  - Příjmení ✅
  - Kategorie ✅
  - Účet pro platby ✅
  - Variabilní symbol ✅
  - specifický symbol ➖
  - Uživatelské jméno ✅
- Jídelníček pro den ✅
  - správný počet jídel ✅
  - jídlo ✅
    - název ✅
    - cena ✅
    - varianta ✅
    - objednáno ✅
    - lze objednat ✅
    - na burze ➖
    - alergeny ➖
      - kódy➖
      - podrobnosti➖
      - název➖
    - rozdělení na kategorie ✅
    - blokováno (vypršela platnost) ✅
- Jídelníček pro měsíc ❌
- Objednávání ✅
  - funguje objednávání✅
  - funguje zrušení✅
- Burza➖
  - získání burzy➖
  - Objednávání z burzy➖
  - vložení jídla na burzu➖
  - zrušit vložení jídla na burzu➖
- Výdejny (jiné lokace) ✅
